@@ -6,7 +6,7 @@ from pandas import DataFrame, Series
 from scipy.optimize import least_squares
 import warnings
 
-def calculate_etr(fo, fm, sigma, par, alpha_phase=True, light_independent=True, dark_sigma=False, etrmax_fitting=True, serodio_sigma=False, light_step_size=None, last_steps_average=False, outlier_multiplier=3, return_data=False, bounds=True, alpha_lims=[0,4], etrmax_lims=[0,2000], method='trf', loss='soft_l1', f_scale=0.1, max_nfev=None, xtol=1e-9):
+def calculate_amplitude_etr(fo, fm, sigma, par, alpha_phase=True, light_independent=True, dark_sigma=False, etrmax_fitting=True, serodio_sigma=False, light_step_size=None, last_steps_average=False, skip_first_light_step=False, outlier_multiplier=3, return_data=False, bounds=True, alpha_lims=[0,4], etrmax_lims=[0,2000], method='trf', loss='soft_l1', f_scale=0.1, max_nfev=None, xtol=1e-9):
       
 	"""
 	
@@ -31,11 +31,13 @@ def calculate_etr(fo, fm, sigma, par, alpha_phase=True, light_independent=True,
 	etrmax_fitting : bool
 		If True, will fit α\ :sup:`ETR` and ETR\ :sub:`max` and manually calculate E\ :sub:'k'. If False, will fit α\ :sup:`ETR` and E\ :sub:'k' and manually calculate ETR\ :sub:`max`.
 	serodio_sigma : bool
-		If True, will apply a correction a Serodio correction for samples that have dark relaxation.
+		If True, will apply a Serodio correction for samples that have dark relaxation.
 	light_step_size : int
 		The number of measurements for initial light step.
 	last_steps_average : bool, default=False,
 		If True, means will be created from the last 3 measurements per light step. Else, mean will be created from entire light step excluding outliers.
+	skip_first_light_step : bool, default=False,
+		If True, will skip the first light step in cases of large changes in F\ :sub:`v`/F\ :sub:`m` between first and second light step for performing light independent calculations.
 	outlier_multiplier : int, default=3
 		The multiplier to apply to the standard deviation for determining the upper and lower limits.
 	return_data : bool, default=False
@@ -116,7 +118,7 @@ def calculate_etr(fo, fm, sigma, par, alpha_phase=True, light_independent=True,
 
 	Example
 	-------
-	>>> res = ppu.calculate_e_dependent_etr(fo, fm, fvfm, sigma, par, return_data=False)
+	>>> res = ppu.calculate_etr(fo, fm, sigma, par, return_data=False)
 	"""
 
 	warnings.simplefilter(action = "ignore", category = RuntimeWarning)
@@ -163,7 +165,13 @@ def calculate_etr(fo, fm, sigma, par, alpha_phase=True, light_independent=True,
 
 	if light_step_size == 1:
 		if light_independent:
-			etr = fvfm / fvfm[0]
+			if skip_first_light_step:
+				etr = fvfm / fvfm[1]
+
+				print('Skipping first light step')
+
+			else:	
+				etr = fvfm / fvfm[0]
 		else:
 			if dark_sigma:
 				etr = (par * mean(sigma[0]) * (fvfm / mean(fvfm[0]))) * 6.022e-3
@@ -467,3 +475,5 @@ def calculate_etr(fo, fm, sigma, par, alpha_phase=True, light_independent=True,
 			else:
 				results = Series([etr_max, alpha, ek, beta_bias, beta_rmse, beta_nrmse, alpha_err, ek_err, beta_nfev, beta_flag, beta_success])
 			return results
+
+
